from . import (
    rev0,
    rev1,
    rev2,
    rev3,
    rev4,
    rev5,
    rev6,
    rev7,
    rev8,
    rev9,
    rev10,
)

revisions = {
    0: rev0,
    1: rev1,
    2: rev2,
    3: rev3,
    4: rev4,
    5: rev5,
    6: rev6,
    7: rev7,
    8: rev8,
    9: rev9,
    10: rev10,
}
